#!/bin/bash
# -----------------------------------------------------------------------
# E.F.Engelhardt, Franzis Verlag, 2016/2107
#-------------------------------------------------------------------------
# Definitionen
#-------------------------------------------------------------------------
EINSNULL="1>/dev/null"
ZWEINULL="2>/dev/null"
#-------------------------------------------------------------------------
# GPIO
GPIO_IMGR=23 # pin 16 - wiring pi 4
GPIO_IMGL=24 # pin 18 - wiring pi 5
GPIO_DEL=25 # pin 22 - wirng pi 6
GPIO_SHUTTER=22 # pin 15 - wiring 3
GPIO_VIDEO=17 # pin 11 - wiring 0
GPIO_LED=18 # pin 12 - wiring 1
#-------------------------------------------------------------------------
# Schalter
iSW_SHOW_IMGR=0
iSW_SHOW_IMGL=0
iSW_SHOW_DEL=0
iSW_SHUTTER=0
iSW_VIDEO=0
#-------------------------------------------------------------------------
# Dateihandling
DEFAULTFILE="himbeerecam.jpg"
FILE_PATH="/home/pi/IMG/"
FILEIMG="IMG_"
FILEEXTJPG=".jpg"
FILENAMEIMG=$FILE_PATH$FILEIMG$(date +"%m-%d-%y_%H%M%S")$FILEEXTJPG
FILENAMEDEFAULT=$FILE_PATH$DEFAULTFILE
MAXFILES=100
myindexnumber=0
SHOW_IMG_CMD="fbi -T 1 -a "

#-------------------------------------------------------------------------
function gpio_init(){
	gpio_export $GPIO_IMGR
	gpio_configure_input $GPIO_IMGR

	gpio_export $GPIO_IMGL
	gpio_configure_input $GPIO_IMGL

	gpio_export $GPIO_DEL
	gpio_configure_input $GPIO_DEL

	gpio_export $GPIO_SHUTTER
	gpio_configure_input $GPIO_SHUTTER

	gpio_export $GPIO_VIDEO
	gpio_configure_input $GPIO_VIDEO

	gpio_export $GPIO_LED
	gpio_configure_output $GPIO_LED
}
#-------------------------------------------------------------------------
function gpio_configure_output() {
	if [ -e "/sys/class/gpio/gpio${1}/direction" ]; then
		echo "out" > "/sys/class/gpio/gpio${1}/direction"
	fi
}
#-------------------------------------------------------------------------
function gpio_configure_input() {
	if [ -e "/sys/class/gpio/gpio${1}/direction" ]; then
		echo "in" > "/sys/class/gpio/gpio${1}/direction"
	fi
}
#-------------------------------------------------------------------------
function gpio_export() {
	echo -n "exporting gpio $1"
	if [ -e "/sys/class/gpio/gpio${1}/" ]; then
		echo "...gpio${1} already exists"
	else
		echo
		echo "${1}" > "/sys/class/gpio/export"
	fi
}
#-------------------------------------------------------------------------
function gpio_unexport() {
	echo -n "unexporting gpio $1"
	if [ -e "/sys/class/gpio/gpio${1}/" ]; then
		echo
		echo "${1}" > "/sys/class/gpio/unexport"
	else
		echo "-> gpio${1} does not exist"
	fi
}
#-------------------------------------------------------------------------
function check_raspicam_2(){
	echo -n "check if raspberry pi camera connected"
	if [ "`vcgencmd get_camera`" = "supported=1 detected=1" ]; then
		echo "OK, RaspiCAM ist installiert."
	else
		echo "\n\nKeine Kamera installiert. Bitte erst installieren."
#		exit 1
	fi
}
#-------------------------------------------------------------------------
function check_raspicam(){
	if [ -e "/home/pi/test.jpg" ]; then rm /home/pi/test.jpg; fi
	raspistill -o /home/pi/test.jpg
 	if [ -e "/home/pi/test.jpg" ]; then
                echo
		echo "OK, RaspiCAM ist installiert."
        else
		echo "\n\nKeine Kamera installiert. Bitte erst installieren."
         fi
}
#-------------------------------------------------------------------------
function toggle_gpio(){
	gport=$1;
	if ! [ -d /sys/class/gpio/gpio$gport ]; then
		echo "$gport" > /sys/class/gpio/export
		echo "out" > /sys/class/gpio/gpio$gport/direction
	fi
	gstatus=$2;
	if [ $gstatus -gt 1 ]; then
		gstatus=1
	fi
	echo "$gstatus" > /sys/class/gpio/gpio$gport/value
}
#-------------------------------------------------------------------------
#
#  START
#
# gpio initialisieren
gpio_init
mkdir -p $FILE_PATH
cd $FILE_PATH
# check ob Kamera vorhanden
check_raspicam
echo "Raspberry Pi FranzisCAM im Einsatz (Beenden mit: CTRL-C)"
while true; do
# wird ein "Schliesser" als Schalter verwendet dann hier 0 als Parameter
# bei einem "Oeffner als Schalter hier 1
#	if [ $(gpio -g read $GPIO_IMGR) -eq  1 ]; then
#		echo "GPIO_IMGR" $GPIO_IMGR "aktiv"
#        elif [ $(gpio -g read $GPIO_DEL) -eq  1 ]; then
#        	echo "GPIO_DEL" $GPIO_DEL "aktiv"
#     	elif [ $(gpio -g read $GPIO_IMGL) -eq  1 ]; then
#        	echo "GPIO_IMGL" $GPIO_IMGL "aktiv"
#        elif [ $(gpio -g read $GPIO_SHUTTER) -eq  1 ]; then
#        	echo "GPIO_SHUTTER" $GPIO_SHUTTER "aktiv"
#        elif [ $(gpio -g read $GPIO_VIDEO) -eq  1 ]; then
#        	echo "GPIO_VIDEO" $GPIO_VIDEO "aktiv"
#	fi
        if [ $(gpio -g read $GPIO_IMGR) -eq  0 ]; then
                echo "GPIO_IMGR" $GPIO_IMGR "gedrueckt"
        elif [ $(gpio -g read $GPIO_DEL) -eq  0 ]; then
                echo "GPIO_DEL" $GPIO_DEL "gedrueckt"
        elif [ $(gpio -g read $GPIO_IMGL) -eq  0 ]; then
                echo "GPIO_IMGL" $GPIO_IMGL "gedrueckt"
		show_IMGL
        elif [ $(gpio -g read $GPIO_SHUTTER) -eq  0 ]; then
                echo "GPIO_SHUTTER" $GPIO_SHUTTER "gedrueckt"
        elif [ $(gpio -g read $GPIO_VIDEO) -eq  0 ]; then
                echo "GPIO_VIDEO" $GPIO_VIDEO "gedrueckt"
        fi
sleep 0.1
done
exit 0
#---------------------- EOF --------------------------------