#!/bin/bash
# -----------------------------------------------------------------------
# E.F.Engelhardt, Franzis Verlag, 2016/2107
# -----------------------------------------------------------------------
# Definitionen
#-------------------------------------------------------------------------
EINSNULL="1>/dev/null"
ZWEINULL="2>/dev/null"
#-------------------------------------------------------------------------
# GPIO
GPIO_IMGR=23 # pin 16 - wiring pi 4
GPIO_IMGL=24 # pin 18 - wiring pi 5
GPIO_DEL=25 # pin 22 - wirng pi 6
GPIO_SHUTTER=22 # pin 15 - wiring 3
GPIO_VIDEO=17 # pin 11 - wiring 0
GPIO_LED=18 # pin 12 - wiring 1
#-------------------------------------------------------------------------
# Schalter
iSW_SHOW_IMGR=0
iSW_SHOW_IMGL=0
iSW_SHOW_DEL=0
iSW_SHUTTER=0
iSW_VIDEO=0
#-------------------------------------------------------------------------
# Dateihandling
ZAEHLER=0 
ZAEHLERNEU=0
DEFAULTFILE="himbeerecam.jpg"
FILE_PATH="/home/pi/IMG/"
FILEIMG="IMG_"
FILEEXTJPG=".jpg"
#FILENAMEIMG=$FILE_PATH"/"$FILEIMG$(date +"%m-%d-%y_%H%M%S")$FILEEXTJPG
#FILENAMEIMG=$FILE_PATH"/"$FILEIMG$ZAEHLERNEU$FILEEXTJPG
FILENAMEDEFAULT=$FILE_PATH$DEFAULTFILE
MAXFILES=100
SHOW_IMG_CMD="fbi -T 1 -a "

#-------------------------------------------------------------------------
function zaehler_init(){
	if [ -e  "/usr/bin/bc" ]; then
		echo -e "\n\n[franzisCAM] OK, bc bereits installiert"
	else
        	echo -e "\n\n[franzisCAM] kein bc installiert, wird nachgeholt.."
		sudo apt-get install bc -y
	fi
}
#-------------------------------------------------------------------------
function setnew_zaehler(){
	#echo "set new zaehler:" $FILE_PATH$FILEIMG*$FILEEXTJPG
	ZAEHLERAKTUELL=`ls -tr $FILE_PATH$FILEIMG*$FILEEXTJPG| tail -1 | cut -d '_' -f 2 | cut -d '.' -f 1`
	if [ ! -z "$ZAEHLERAKTUELL" ];then
		ZAEHLERNEU=`echo $ZAEHLERAKTUELL+1 | bc`
   	else
		ZAEHLERNEU=0
	fi
}
#-------------------------------------------------------------------------
function gpio_init(){
	gpio_export $GPIO_IMGR
	gpio_configure_input $GPIO_IMGR

	gpio_export $GPIO_IMGL
	gpio_configure_input $GPIO_IMGL

	gpio_export $GPIO_DEL
	gpio_configure_input $GPIO_DEL

	gpio_export $GPIO_SHUTTER
	gpio_configure_input $GPIO_SHUTTER

	gpio_export $GPIO_VIDEO
	gpio_configure_input $GPIO_VIDEO

	gpio_export $GPIO_LED
	gpio_configure_output $GPIO_LED
}
#-------------------------------------------------------------------------
function gpio_configure_output() {
	if [ -e "/sys/class/gpio/gpio${1}/direction" ]; then
		echo "out" > "/sys/class/gpio/gpio${1}/direction"
	fi
}
#-------------------------------------------------------------------------
function gpio_configure_input() {
	if [ -e "/sys/class/gpio/gpio${1}/direction" ]; then
		echo "in" > "/sys/class/gpio/gpio${1}/direction"
	fi
}
#-------------------------------------------------------------------------
function gpio_export() {
	echo -n "exporting gpio $1"
	if [ -e "/sys/class/gpio/gpio${1}/" ]; then
		echo "...gpio${1} already exists"
	else
		echo
		echo "${1}" > "/sys/class/gpio/export"
	fi
}
#-------------------------------------------------------------------------
function gpio_unexport() {
	echo -n "unexporting gpio $1"
	if [ -e "/sys/class/gpio/gpio${1}/" ]; then
		echo
		echo "${1}" > "/sys/class/gpio/unexport"
	else
		echo "-> gpio${1} does not exist"
	fi
}
#-------------------------------------------------------------------------
function check_raspicam_2(){
	echo "[franzisCAM] ]check if raspberry pi camera connected"
	if [ "`vcgencmd get_camera`" = "supported=1 detected=1" ]; then
		echo -e "\n\n[franzisCAM] OK, RaspiCAM ist installiert."
	else
		echo -e "\n\n[franzisCAM] Keine Kamera installiert. Bitte erst installieren."
#		exit 1
	fi
}
#-------------------------------------------------------------------------
function check_raspicam(){
	if [ -e "/home/pi/test.jpg" ]; then rm /home/pi/test.jpg; fi
	raspistill -o /home/pi/test.jpg
 	if [ -e "/home/pi/test.jpg" ]; then
                echo
		echo -e "\n\n[franzisCAM] OK, RaspiCAM ist installiert."
        else
		echo -e "\n\n[franzisCAM] Keine Kamera installiert. Bitte erst installieren."
		exit 1
         fi
}
#-------------------------------------------------------------------------
function toggle_gpio(){
	gport=$1;
	if ! [ -d /sys/class/gpio/gpio$gport ]; then
		echo "$gport" > /sys/class/gpio/export
		echo "out" > /sys/class/gpio/gpio$gport/direction
	fi
	gstatus=$2;
	if [ $gstatus -gt 1 ]; then
		gstatus=1
	fi
	echo "$gstatus" > /sys/class/gpio/gpio$gport/value
}
#-------------------------------------------------------------------------
function takeSnapshot() {
	# eigenbau franzisCAM -n
	setnew_zaehler
	FILENAMEIMG=$FILE_PATH"/"$FILEIMG$ZAEHLERNEU$FILEEXTJPG
	if [ -e  "/usr/bin/franzisCAM" ]; then
		echo -e "\n\n[franzisCAM] OK, franzisCAM bereits installiert"
		franzisCAM -n -o $FILENAMEIMG
		echo "[franzisCAM] Aufnahme:" $FILEIMG$ZAEHLERNEU$FILEEXTJPG " wurde auf der Speicherkarte gespeichert"
	else
        echo -e "\n\n[franzisCAM] kein franzisCAM installiert, Prfung ob raspistill vorhanden.."
		if [ -e  "/usr/bin/raspistill" ]; then
			echo -e "\n\n[franzisCAM] OK, raspistill ist installiert"
			raspistill -o $FILENAMEIMG #raspistill -n -o $FILENAMEIMG
			echo "[franzisCAM] Aufnahme:" $FILEIMG$ZAEHLERNEU$FILEEXTJPG " wurde auf der Speicherkarte gespeichert"
		else
			echo -e "\n\n[franzisCAM] Weder franzisCAM noch raspistill installiert.. Keine Aufnahmen mglich!"
		fi
	fi
}
#-------------------------------------------------------------------------
#
#  START
#
# gpio initialisieren
gpio_init
mkdir -p $FILE_PATH
cd $FILE_PATH
clear
# check ob Kamera vorhanden
check_raspicam
echo "--------------------------------------------------------------------------"
echo "[franzisCAM] - Raspberry Pi FranzisCAM im Einsatz (Beenden mit: CTRL-C)"
echo "--------------------------------------------------------------------------"

zaehler_init
while true; do
# wird ein "Schliesser" als Schalter verwendet dann hier 0 als Parameter
# bei einem "Oeffner als Schalter hier 1
#	if [ $(gpio -g read $GPIO_IMGR) -eq  1 ]; then
#		echo "[franzisCAM] GPIO_IMGR" $GPIO_IMGR "aktiv"
#        elif [ $(gpio -g read $GPIO_DEL) -eq  1 ]; then
#        	echo "[franzisCAM] GPIO_DEL" $GPIO_DEL "aktiv"
#     	elif [ $(gpio -g read $GPIO_IMGL) -eq  1 ]; then
#        	echo "[franzisCAM] GPIO_IMGL" $GPIO_IMGL "aktiv"
#        elif [ $(gpio -g read $GPIO_SHUTTER) -eq  1 ]; then
#        	echo "[franzisCAM] GPIO_SHUTTER" $GPIO_SHUTTER "aktiv"
#        elif [ $(gpio -g read $GPIO_VIDEO) -eq  1 ]; then
#        	echo "[franzisCAM] GPIO_VIDEO" $GPIO_VIDEO "aktiv"
#	fi
        if [ $(gpio -g read $GPIO_IMGR) -eq  0 ]; then
                echo "[franzisCAM] GPIO_IMGR" $GPIO_IMGR "gedrueckt"
        elif [ $(gpio -g read $GPIO_DEL) -eq  0 ]; then
                echo "[franzisCAM] GPIO_DEL" $GPIO_DEL "gedrueckt"
        elif [ $(gpio -g read $GPIO_IMGL) -eq  0 ]; then
                echo "[franzisCAM] GPIO_IMGL" $GPIO_IMGL "gedrueckt"
#show_IMGL
        elif [ $(gpio -g read $GPIO_SHUTTER) -eq  0 ]; then
                echo "[franzisCAM] GPIO_SHUTTER" $GPIO_SHUTTER "gedrueckt"
		takeSnapshot
       elif [ $(gpio -g read $GPIO_VIDEO) -eq  0 ]; then
                echo "[franzisCAM] GPIO_VIDEO" $GPIO_VIDEO "gedrueckt"
        fi
sleep 0.1
done
exit 0
# --------------------------- EOF ---------------------------------------
