#!/bin/bash
# -----------------------------------------------------------------------
# E.F.Engelhardt, Franzis Verlag, 2016/2107
#-------------------------------------------------------------------------
# Definitionen
#-------------------------------------------------------------------------
EINSNULL="1>/dev/null"
ZWEINULL="2>/dev/null"
#-------------------------------------------------------------------------
# GPIO
GPIO_IMGR=23 # pin 16 - wiring pi 4
GPIO_IMGL=24 # pin 18 - wiring pi 5
GPIO_DEL=25 # pin 22 - wirng pi 6
GPIO_SHUTTER=22 # pin 15 - wiring 3
GPIO_VIDEO=17 # pin 11 - wiring 0
GPIO_LED=18 # pin 12 - wiring 1
#-------------------------------------------------------------------------
# Schalter
SW_SHOW_IMGR=0
SW_SHOW_IMGL=0
SW_SHOW_DEL=0
SW_SHUTTER=0
SW_VIDEO=0
SW_GPSD=0
# Schalterzaehler
iSW_SHOW_IMGR=0
iSW_SHOW_IMGL=0
iSW_SHOW_DEL=0
iSW_SHUTTER=0
iSW_VIDEO=0
iSW_GPSD=0
#-------------------------------------------------------------------------
# Dateihandling
ZAEHLER=0 
ZAEHLERNEU=0
DEFAULTFILE="himbeerecam.jpg"
FILE_PATH="/home/pi/IMG/"
FILEIMG="IMG_"
FILEEXTJPG=".jpg"
#FILENAMEIMG=$FILE_PATH"/"$FILEIMG$(date +"%m-%d-%y_%H%M%S")$FILEEXTJPG
#FILENAMEIMG=$FILE_PATH"/"$FILEIMG$ZAEHLERNEU$FILEEXTJPG
FILENAMEDEFAULT=$FILE_PATH$DEFAULTFILE
MAXFILES=100
SHOW_IMG_CMD="fbi -T 1 -a "

#-------------------------------------------------------------------------
function fbi_init(){
        if [ -e  "/usr/bin/fbi" ]; then
			echo -e "\n\n[franzisCAM] OK, fbi bereits installiert";
        else
            echo -e "\n\n[franzisCAM] kein fbi installiert, wird nachgeholt..";
            sudo apt-get install fbi -y;
        fi
}
#-------------------------------------------------------------------------
function zaehler_init(){
	if [ -e  "/usr/bin/bc" ]; then
		echo -e "\n\n[franzisCAM] OK, bc bereits installiert";
	else
        echo -e "\n\n[franzisCAM] kein bc installiert, wird nachgeholt..";
		sudo apt-get install bc -y;
	fi
}
#-------------------------------------------------------------------------
function setnew_zaehler(){
	#echo "set new zaehler:" $FILE_PATH$FILEIMG*$FILEEXTJPG
	ZAEHLERAKTUELL=`ls -tr $FILE_PATH$FILEIMG*$FILEEXTJPG| tail -1 | cut -d '_' -f 2 | cut -d '.' -f 1`;
	if [ ! -z "$ZAEHLERAKTUELL" ];then
		ZAEHLERNEU=`echo $ZAEHLERAKTUELL+1 | bc`;
   	else
		ZAEHLERNEU=0;
	fi
}
#-------------------------------------------------------------------------
function init_gpsd(){
	# GPS angeschlossen?
	TXT="[franzisCAM] init_gps gestartet"
	if [ "$(ls /dev/ttyUSB0)" ]; then
		TXT="${TXT}  \n-> GPS-USB-Stick an franzisCAM angeschlossen"
		if [ -e  "/usr/bin/gpsd" ]; then
			echo -e "\n\n[franzisCAM] OK, GPS Daemon bereits installiert";
			sudo killall gpsd;	# gps Bug, neustart
			sudo gpsd /dev/ttyUSB0 -F /var/run/gpsd.sock;
		else
			echo -e "\n\n[franzisCAM] kein GPS Daemon  installiert, wird nachgeholt..";
			sudo apt-get install gpsd -y;
			sudo killall gpsd;	# gps Bug, neustart
			sudo gpsd /dev/ttyUSB0 -F /var/run/gpsd.sock;
			LONGITUDE=`gpspipe -w -n 5 | grep lon | grep -i -m 1 tpv | cut -d ',' -f 8 | cut -d ':' -f 2`;
			LATITUDE=`gpspipe -w -n 5 | grep lat | grep -i -m 1 tpv | cut -d ',' -f 7 | cut -d ':' -f 2`;
			DATE_FILE=`date +%Y-%m-%d_%H-%M`;
			DATE_EXIF=`date +%Y:%m:%d`;
			TIME_EXIF=`date +%H:%M:%S`;
			echo -e "\n\n[franzisCAM] GPS-Parameter gesetzt.";
		fi;
	#sudo apt-get install libimage-exiftool-perl
		if [ -e  "/usr/bin/exiftool" ]; then
			echo -e "\n\n[franzisCAM] OK, exiftool bereits installiert";
		else
			echo -e "\n\n[franzisCAM] kein exiftool installiert, wird nachgeholt..";
			sudo apt-get install libimage-exiftool-perl -y;
		fi;
		iSW_GPSD=1;	
	else
		TXT="${TXT}  \n-> kein GPS-USB-Stick an franzisCAM angeschlossen";
		iSW_GPSD=0;
	fi;
	echo ${TXT};
}
#-------------------------------------------------------------------------
function gpio_init(){
	gpio_export $GPIO_IMGR
	gpio_configure_input $GPIO_IMGR

	gpio_export $GPIO_IMGL
	gpio_configure_input $GPIO_IMGL

	gpio_export $GPIO_DEL
	gpio_configure_input $GPIO_DEL

	gpio_export $GPIO_SHUTTER
	gpio_configure_input $GPIO_SHUTTER

	gpio_export $GPIO_VIDEO
	gpio_configure_input $GPIO_VIDEO

	gpio_export $GPIO_LED
	gpio_configure_output $GPIO_LED
}
#-------------------------------------------------------------------------
function gpio_configure_output() {
	if [ -e "/sys/class/gpio/gpio${1}/direction" ]; then
		echo "out" > "/sys/class/gpio/gpio${1}/direction";
	fi
}
#-------------------------------------------------------------------------
function gpio_configure_input() {
	if [ -e "/sys/class/gpio/gpio${1}/direction" ]; then
		echo "in" > "/sys/class/gpio/gpio${1}/direction";
	fi
}
#-------------------------------------------------------------------------
function gpio_export() {
	echo -n "exporting gpio $1"
	if [ -e "/sys/class/gpio/gpio${1}/" ]; then
		echo "...gpio${1} already exists";
	else
		echo
		echo "${1}" > "/sys/class/gpio/export";
	fi
}
#-------------------------------------------------------------------------
function gpio_unexport() {
	echo -n "unexporting gpio $1";
	if [ -e "/sys/class/gpio/gpio${1}/" ]; then
		echo
		echo "${1}" > "/sys/class/gpio/unexport";
	else
		echo "-> gpio${1} does not exist";
	fi
}
#-------------------------------------------------------------------------
function check_raspicam_2(){
	echo "[franzisCAM] ]check if raspberry pi camera connected";
	if [ "`vcgencmd get_camera`" = "supported=1 detected=1" ]; then
		echo -e "\n\n[franzisCAM] OK, RaspiCAM ist installiert.";
	else
		error_exit "\n\n[franzisCAM] Keine Kamera installiert. Bitte erst installieren.";
	fi
}
#-------------------------------------------------------------------------
function check_raspicam(){
	if [ -e "/home/pi/test.jpg" ]; then rm /home/pi/test.jpg; fi
	raspistill -o /home/pi/test.jpg;
 	if [ -e "/home/pi/test.jpg" ]; then
        echo;
		echo -e "\n\n[franzisCAM] OK, RaspiCAM ist installiert.";
    else
		error_exit "\n\n[franzisCAM] Keine Kamera installiert. Bitte erst installieren.";
    fi;
}
#-------------------------------------------------------------------------
function toggle_gpio(){
	gport=$1;
	if ! [ -d /sys/class/gpio/gpio$gport ]; then
		echo "$gport" > /sys/class/gpio/export;
		echo "out" > /sys/class/gpio/gpio$gport/direction;
	fi;
	gstatus=$2;
	if [ $gstatus -gt 1 ]; then
		gstatus=1;
	fi;
	echo "$gstatus" > /sys/class/gpio/gpio$gport/value;
}
#-------------------------------------------------------------------------
function exif2image(){
	# Pruefung ob GPS aktiv?
	if [ "$iSW_GPSD" -eq 0 ]; then # kein GPS
		echo "[franzisCAM] Kein GPS installiert.";
	else
		# gps aktiv
		echo "[franzisCAM] Derzeitige GPS-Position: $LONGITUDE Laengengrad und $LATITUDE Breitengrad";
		echo "[franzisCAM] Es wird $FILE verarbeitet am $DATE_EXIF $TIME_EXIF";
		if [ "$FILENAMEIMG" ]; then
		tmpFILENAMEIMG="tmp.jpg"
		# echo "TEMP DATEI" = $tmpFILENAMEIMG
	        exiftool -overwrite_original -xmp:dateTimeOriginal="$DATE_EXIF $TIME_EXIF" -GPSLongitudeRef=E -GPSLongitude=$LONGITUDE -GPSLatitudeRef=N -GPSLatitude=$LATITUDE $FILENAMEIMG -o $tmpFILENAMEIMG;
		mv $tmpFILENAMEIMG $FILENAMEIMG -f;
       	else
       		error_exit "[franzisCAM] Kann keine EXIF-Informationen der Aufnahme hinzufuegen, da keine Aufnahme vorhanden! Abbruch.";
		fi;
	fi;
}
#-------------------------------------------------------------------------
function takeSnapshot() {
	# eigenbau franzisCAM -n
	setnew_zaehler;
	FILENAMEIMG=$FILE_PATH$FILEIMG$ZAEHLERNEU$FILEEXTJPG;
	if [ -e  "/usr/bin/franzisCAM" ]; then
		echo -e "\n\n[franzisCAM] OK, franzisCAM bereits installiert";
		franzisCAM -n -o $FILENAMEIMG;
		exif2image;
		echo "[franzisCAM] Aufnahme:" $FILEIMG$ZAEHLERNEU$FILEEXTJPG " wurde auf der Speicherkarte gespeichert";
	else
        echo -e "\n\n[franzisCAM] kein franzisCAM installiert, Pruefung ob raspistill vorhanden..";
		if [ -e  "/usr/bin/raspistill" ]; then
			echo -e "\n\n[franzisCAM] OK, raspistill ist installiert";
			raspistill -o $FILENAMEIMG #raspistill -n -o $FILENAMEIMG;
			exif2image;
			echo "[franzisCAM] Aufnahme:" $FILEIMG$ZAEHLERNEU$FILEEXTJPG " wurde auf der Speicherkarte gespeichert";
		else
			error_exit "\n\n[franzisCAM] Weder franzisCAM noch raspistill installiert.. Keine Aufnahmen moeglich!";
		fi;
	fi;
}
#-------------------------------------------------------------------------
function inc_switch(){
        local name_switch=${1};
        local switch_wert=${2};
        echo "Uebergeben wurde :" $name_switch " und " $switch_wert;
        local switch_wertneu=0;
        if [ ! -z "$switch_wert" ];then
                local switch_wertneu=`echo $switch_wert+1 | bc`;
        fi;
        case "$name_switch" in
                "SW_SHOW_IMGR") # SW_SHOW_IMGR
#               iSW_SHOW_IMGR=$switch_wertneu;
#               echo "IMGR+1"
                iSW_SHOW_IMGR=$switch_wertneu
                ;;

                "SW_SHOW_IMGL") # SW_SHOW_IMGL
                iSW_SHOW_IMGL=$switch_wertneu
                ;;

                "SW_SHOW_DEL") # SW_DEL_IMG
                iSW_SHOW_DEL=$switch_wertneu
                ;;

                "SW_SHUTTER") # SW_SHUTTER
                iSW_SHUTTER=$switch_wertneu
                ;;

                "SW_VIDEO") # SW_VIDEO
                iSW_VIDEO=$switch_wertneu
                ;;
        esac
}
#-------------------------------------------------------------------------
function desc_switch(){
        local name_switch=${1};
        local switch_wert=${2};
        echo "Uebergeben wurde :" $name_switch " und " $switch_wert;
        local switch_wertneu=0;
        if [ ! -z "$switch_wert" ];then
                local switch_wertneu=`echo $switch_wert-1 | bc`;
        fi
        if [ "$switch_wertneu" -lt 0 ];then
                switch_wertneu=0;
        fi
        case "$name_switch" in
                "SW_SHOW_IMGR") # SW_SHOW_IMGR
#               iSW_SHOW_IMGR=$switch_wertneu;
#               echo "IMGR-1"
                iSW_SHOW_IMGR=$switch_wertneu
                ;;

                "SW_SHOW_IMGL") # SW_SHOW_IMGL
                iSW_SHOW_IMGL=$switch_wertneu 
                ;;

                "SW_SHOW_DEL") # SW_DEL_IMG
                iSW_SHOW_DEL=$switch_wertneu
                ;;

                "SW_SHUTTER") # SW_SHUTTER
                iSW_SHUTTER=$switch_wertneu
                ;;

                "SW_VIDEO") # SW_VIDEO
                iSW_VIDEO=$switch_wertneu
                ;;
        esac
}
#-------------------------------------------------------------------------
function showImage() {
	# wegen memory fehler vorsichtshalber offene Framebuffer entfernen
	sudo killall -9 fbi;
	if cd $FILE_PATH; then
		#hole Filenamen zu Indexnummer
		#Bekannt: $myindexnumber
		#local showIMGfile=$(getFileNameFromIndex);
		# local showIMGfile=$(getFileNameFromIndex) $myindexnumber
		getFileNameFromIndex $myindexnumber;
		fbi -T 1 -a $showIMGfile 2>/dev/null;
		echo "[franzisCAM] Anzeige von: $showIMGfile";
		# eventuell mit Pfad zusammen dann aufrufen von Bildanzeige
	else
		error_exit "[franzisCAM] Kann nicht das Verzeichnis wechseln! Abbruch."
	fi
}
#-------------------------------------------------------------------------
function deleteImage() {
	cd $FILE_PATH;
	#hole Filenamen zu Indexnummer
	#Bekannt: $myindexnumber
	#local showIMGfile=$(getFileNameFromIndex);
	# local showIMGfile=$(getFileNameFromIndex) $myindexnumber
	if cd $FILE_PATH; then
		getFileNameFromIndex $myindexnumber;
		rm $showIMGfile -f 2>/dev/null;
		echo "[franzisCAM] $showIMGfile wurde geloescht";
	else
		error_exit "[franzisCAM] Kann nicht das Verzeichnis wechseln! Abbruch."
	fi
}
#-------------------------------------------------------------------------
# Hilfskruecke fuer Dateinamen in 
# function showImage benoetigt
function getFileNameFromIndex() {
	cd $FILE_PATH;
	if cd $FILE_PATH; then
		local arr=( $(ls $FILEIMG*$FILEEXTJPG -atr 2>/dev/null ));
		if [ ${#arr[@]} = "0" ];then 
			#local myfilename= 'himbeerecam.jpg'
			local myfilename=$FILENAMEDEFAULT;
		else
			#local myfilename =${arr[$myindexnumber]}
			echo "[franzisCAM] DATEINAME =" ${arr[${1}]};
			myfilename=`echo ${arr[${1}]}`
			#local myfilename =${arr[${1}]};
		fi;
		echo "[franzisCAM] Index: $myindexnumber Dateiname: $myfilename";
		showIMGfile=$myfilename;
	else
		error_exit "[franzisCAM] Kann nicht das Verzeichnis wechseln! Abbruch."
	fi

}
#-------------------------------------------------------------------------
function showSplashImage() {
	local myfilename=$DEFAULTFILE;
	echo "[franzisCAM] $myfilename";
	showIMGfile=$myfilename;
}
#-------------------------------------------------------------------------
function getIndexNumberLast() {
	if [ `find $FILE_PATH -type f | wc -l` = "0" ]; then 
		echo "[franzisCAM] Keine Dateien vorhanden in" $FILE_PATH;
		myindexnumber='0'; 
	else 
		local arr=( $(ls $FILEIMG*$FILEEXTJPG -atr 2>/dev/null ))
		if [ ${#arr[@]} = "0" ];then
			myindexnumber='0';
		else
			# myindexnumber=${#arr[@]}; absolute Anzahl
			myindexnumber=`echo ${#arr[@]}-1 | bc`;
		fi;
	fi;
	echo "[franzisCAM] Zeiger: $myindexnumber";
}
#-------------------------------------------------------------------------
function getIndexNumberFirst() {
        myindexnumber=0;
        echo "[franzisCAM] Zeiger: $myindexnumber";
}
#-------------------------------------------------------------------------
function error_exit
{
	echo "$1" 1>&2
	exit 1
}
#-------------------------------------------------------------------------
#
#  START
#
function init(){
	# gpio initialisieren
	gpio_init;
	if cd $FILE_PATH; then
		#mkdir -p $FILE_PATH;
		#cd $FILE_PATH
		clear;
		# check ob Kamera vorhanden
		check_raspicam;
		echo "--------------------------------------------------------------------------";
		echo "[franzisCAM] - Raspberry Pi franzisCAM v1 im Einsatz (Beenden mit: CTRL-C)";
		echo "--------------------------------------------------------------------------";
		zaehler_init;
		fbi_init;
	else
		error_exit "[franzisCAM] Kann nicht das Verzeichnis wechseln! Abbruch."
	fi;
}
#------------------------------------------------------------------------
function inc_myindex(){
	ZAEHLERAKTUELL=$myindexnumber
	if [ ! -z "$ZAEHLERAKTUELL" ];then
		myindexnumber=`echo $ZAEHLERAKTUELL+1 | bc`;
   	else
		myindexnumber=0;
	fi
}
#-------------------------------------------------------------------------
function desc_myindex(){
	ZAEHLERAKTUELL=$myindexnumber
	if [ ! -z "$ZAEHLERAKTUELL" ];then
		myindexnumber=`echo $ZAEHLERAKTUELL-1 | bc`;
   	else
		myindexnumber=0;
	fi
}
#-------------------------------------------------------------------------

#-------------------------------------------------------------------------
# start MAIN

init
#------------ fuer debugzwecke ----------------------
schalter="SW_SHOW_IMGR";
wert=$iSW_SHOW_IMGR;
inc_switch $schalter $wert;
echo "Aufruf : inc_switch" $schalter $wert;
echo "Wert neu fuer schalter = " $iSW_SHOW_IMGR;
if [ "$iSW_SHOW_IMGR" -eq 1 ]; then
        echo "Wert ist eins";
else
        echo "Wert ist nicht eins";
fi
desc_switch $schalter $iSW_SHOW_IMGR;
echo "Aufruf : desc_switch" $schalter $wert;
echo "Wert neu nach Desc fuer Schalter = " $iSW_SHOW_IMGR;
if [ "$iSW_SHOW_IMGR" -eq 0 ]; then
        echo "Wert ist null";
else
        echo "Wert ist nicht null";
fi

#------------ ende fuer debugzwecke ----------------------
while true; do
        if [ $(gpio -g read $GPIO_IMGR) -eq  0 ]; then
            echo "[franzisCAM] GPIO_IMGR" $GPIO_IMGR "gedrueckt";
            inc_switch SW_SHOW_IMGR $iSW_SHOW_IMGR;
            if [ "$iSW_SHOW_DEL" -eq 1 ];then # Kommt aus DEL
            	echo "[franzisCAM] Delete-Button wurde zuvor gedrueckt";
            else
            	echo "[franzisCAM] Delete-Button wurde nicht vorher gedrueckt";
            	iSW_SHOW_DEL=0;
            fi;
            if [ "$iSW_SHOW_IMGR" -eq 1 ]; then # erster druck
            	if [ "$iSW_SHOW_IMGL" -eq 1 ]; then # vorher bereits "L" gedrueckt
            		echo "[franzisCAM] R-Button -> vorher L-Button gedrueckt";
            		echo "[franzisCAM] Erhoehe Zeiger um eins und zeige Datei";
            		# springe eine Datei weiter und zeige diese an
					getIndexNumberFirst;
					inc_myindex;
                    # echo "INDEX ist hier " $myindexnumber;
                    showImage;
            	else
            		# springe zu letzter Datei
            		# zeige letzte Aufnahme / Vorschaubild in Verzeichnis an
                    getIndexNumberLast;
                    # echo "INDEX ist hier " $myindexnumber;
                    showImage;
            		echo "[franzisCAM] R-Button -> kein vorheriges R/L-Event";
            		echo "[franzisCAM] Zeiger auf letzte Aufnahme und Anzeige";
            	fi;
            else
            	# springe an anfang in Verzeichnisliste &
            	# zeige erste Aufnahme / Vorschaubild in Verzeichnis an
            	echo "[franzisCAM] R-Button -> vorher R-Button gedrueckt, Zeiger auf naechste Aufnahme";
            	if [ "$iSW_SHOW_IMGR" -gt 1 ]; then
            		iSW_SHOW_IMGR=1;
                    #getIndexNumberFirst;
					inc_myindex;
					tmp_myindexnumber=$myindexnumber;
					getIndexNumberLast;
					max_myindexnumber=$myindexnumber;
					if [ "$tmp_myindexnumber" -ge "$max_myindexnumber" ]; then
						myindexnumber=0; # Springe an Anfang
					else
						myindexnumber=$tmp_myindexnumber;
					fi;
					# echo "INDEX ist hier " $myindexnumber;
					showImage;
            	fi;
            fi;
            iSW_SHOW_IMGL=0;
        elif [ $(gpio -g read $GPIO_IMGL) -eq  0 ]; then
            echo "[franzisCAM] GPIO_IMGL" $GPIO_IMGL "gedrueckt";
            inc_switch SW_SHOW_IMGL $iSW_SHOW_IMGL
            if [ "$iSW_SHOW_DEL" -eq 1 ];then # Kommt aus DEL
                echo "[franzisCAM] Delete-Button wurde zuvor gedrueckt";
            else
            	echo "[franzisCAM] Delete-Button wurde nicht vorher gedrueckt";
                iSW_SHOW_DEL=0;
            fi;
            if [ "$iSW_SHOW_IMGL" -eq 1 ];then # erster druck
            	if [ "$iSW_SHOW_IMGR" -eq 1 ];then # vorher bereits "R" gedrueckt
            		echo "[franzisCAM] L-Button -> vorher R-Button gedrueckt";
            		echo "[franzisCAM] Erniedrige Zeiger um eins und zeige Datei";
            		# springe eine Datei zurueck und zeige diese an
                    getIndexNumberLast;
					desc_myindex;
                    # echo "INDEX ist hier " $myindexnumber;
            	else
            		echo "[franzisCAM] L-Button -> kein vorheriges L/R-Event";
            		echo "[franzisCAM] Zeiger auf erste Aufnahme und Anzeige";
					#	myindexnumber = $(getIndexNumberFirst);
					#	myindexnumber =`getIndexNumberFirst`;
					getIndexNumberFirst;
					# echo "INDEX ist hier " $myindexnumber;
            		# springe zu erster Datei
            		# zeige erste Aufnahme / Vorschaubild in Verzeichnis an
            	fi;
				showImage;
            else
            	echo "[franzisCAM] L-Button -> vorher L-Button gedrueckt, Zeiger auf letzte Aufnahme";
            	# springe an Ende in Verzeichnisliste &
            	# zeige letzte Aufnahme / Vorschaubild in Verzeichnis an
            	if [ "$iSW_SHOW_IMGL" -gt 1 ]; then
            		iSW_SHOW_IMGL=1;
                fi;
                #getIndexNumberLast;
				desc_myindex;
				if [ "$myindexnumber" -le 0 ]; then 
					getIndexNumberLast;
				fi; 
                # echo "INDEX ist hier " $myindexnumber;
                showImage;
            fi;
            iSW_SHOW_IMGR=0;
        elif [ $(gpio -g read $GPIO_DEL) -eq  0 ]; then
            echo "[franzisCAM] GPIO_DEL" $GPIO_DEL "gedrueckt";
            inc_switch SW_SHOW_DEL $iSW_SHOW_DEL;
			#echo "iSW_SHOW_DEL = " $iSW_SHOW_DEL
            if [ "$iSW_SHOW_DEL" -eq 1 ];then # erster druck
            	echo "[franzisCAM] DEL-Button -> Zeiger auf letzte Aufnahme";
            	# zeige letzte Bildaufnahme X an
            	inc_switch SW_SHOW_IMGR $iSW_SHOW_IMGR;
            	# springe zu letzter Datei
            	# zeige letzte Aufnahme / Vorschaubild in Verzeichnis an
                getIndexNumberLast;
                # echo "INDEX ist hier " $myindexnumber;
                showImage;
            else
            	echo "[franzisCAM] DEL-Button -> VORHER SCHON DEL-Button gedrueckt -> LOESCHEN";
            	# zweites Druecken -> dann angezeigte Datei loeschen
            	deleteImage;
            	# Status resetten
            	iSW_SHOW_DEL=0;
            	inc_switch SW_SHOW_IMGR $iSW_SHOW_IMGR;
            	# springe zu letzter Datei
                getIndexNumberLast;
                # echo "INDEX ist hier " $myindexnumber;
                showImage;
            fi;
            iSW_SHOW_IMGL=0;
            iSW_SHOW_IMGR=0;
       	elif [ $(gpio -g read $GPIO_SHUTTER) -eq  0 ]; then
            echo "[franzisCAM] GPIO_SHUTTER" $GPIO_SHUTTER "gedrueckt";
            inc_switch SW_SHUTTER $iSW_SHUTTER;
            iSW_SHOW_IMGL=0;
            iSW_SHOW_IMGR=0;
            takeSnapshot;
			# zeige das Bild gleich an
			getIndexNumberLast;
			showImage;
        elif [ $(gpio -g read $GPIO_VIDEO) -eq  0 ]; then
            echo "[franzisCAM] GPIO_VIDEO" $GPIO_VIDEO "gedrueckt";
            inc_switch SW_VIDEO $iSW_VIDEO;
            iSW_SHOW_IMGL=0;
            iSW_SHOW_IMGR=0;
        fi;
sleep 0.1;
done

exit 0
# --------------------------- EOF ---------------------------------------
