# -*- coding: utf-8 -*- 
#!/usr/bin/python
#------------------------------------------------------------------------   
# E.F.Engelhardt, Franzis Verlag, 2016
# ----------------------------------------------------------------------- 
# Das Skript nutzt die Analog-Eingaenge des MCP3008 IC 
# und liest diese ueber SPI Bus aus
#
# mcp3008-step3.py
# -----------------------------------------------------------------------
import spidev
# wget https://raw.github.com/doceme/py-spidev/master/setup.py
# wget https://raw.github.com/doceme/py-spidev/master/spidev_module.c
import time
import os
# SPI Objekt erstellen
spi = spidev.SpiDev()
spi.open(0,0)

# Funktion um Daten aus dem MCP3008 IC zu lesen
# Kanalzaehlung von 0-7
def getadcChannel(channel):
  # Nur Kanal 0-7 erlaubt
  if ((channel > 7) or (channel < 0)):
                    return -1
  # Start Bit senden
  # Send start bit, sgl/diff, odd/sign, MSBF
  # channel = 0 sends 0000 0001 1000 0000 0000 0000
  # channel = 1 sends 0000 0001 1100 0000 0000 0000
  # sgl/diff = 1; odd/sign = channel; MSBF = 0
  rdata = spi.xfer2([1,(8+channel)<<4,0])
  data = ((rdata[1]&3) << 8) + rdata[2]
  return data

# Funktion um Werte in Spannungswerte zu konvertieren
# (auf 2^10 Einheiten)
def convertVolts(data,places):
  volts = (data * 3.3) / 1023 # 3.3V Referenzspannung!
  volts = round(volts,places) # und runden
  return volts

# ----------------------------------------------
# Start Python-Skript
# ----------------------------------------------
os.system('clear')
print "[Lichtsensor] Lichtsmessung..." 
# Kanalnummer auswaehlen
poti_channel  = 0
light1_channel = 1
light2_channel = 2
light3_channel = 3
moisture_channel = 4
# max 7 !
#
m1 = 1.39733
b1 = 36.611
m2 = 1.39733
b2 = 36.611
m3 = 1.39733
b3 = 36.611
# Pause zwischen Messungen 
delay = 5
# Anzahl der Dezimalstellen
places = 3
try: 
# Dauer-Schleife
  while True:
    # Potentiometer /  Sensor
    poti_level = getadcChannel(poti_channel)
    poti_volts = convertVolts(poti_level,places)
    # Lese den ersten Lichtsensor an Kanalanschluss 1
    light1_level = getadcChannel(light1_channel)
    light1_volts = convertVolts(light1_level,places)
    light1_luminosity = (m1 * light1_level) + b1
    # Lese den ersten Lichtsensor an Kanalanschluss 2
    light2_level = getadcChannel(light2_channel)
    light2_volts = convertVolts(light2_level,places)
    light2_luminosity = (m2 * light2_level) + b2
    # Lese den ersten Lichtsensor an Kanalanschluss 3
    light3_level = getadcChannel(light3_channel)
    light3_volts = convertVolts(light3_level,places)
    light3_luminosity = (m3 * light3_level) + b3
    # Datenausgabe
    print "--------------------------------------------"  
    print("Potentiometer  : {} ({}V)".format(poti_level,poti_volts))
    print("Lichtsensor <1>: {} ({}V) entspricht {} Lux".format(light1_level,light1_volts, light1_luminosity))  
    print("Lichtsensor <2>: {} ({}V) entspricht {} Lux".format(light2_level,light2_volts, light2_luminosity))
    print("Lichtsensor <3>: {} ({}V) entspricht {} Lux".format(light3_level,light3_volts, light3_luminosity))
    # und warten bis zur naechsten Messung
    time.sleep(delay)
except KeyboardInterrupt:
    # CTRL-C gedrueckt
    # Reset GPIO
    print "[Lichtsensor] Messung abgebrochen."
# ----------------------- EOF  ---------------------------
