# -*- coding: utf-8 -*-
#!/usr/bin/python
#------------------------------------------------------------------------
# E.F. Engelhardt, Franzis Verlag, 2016
# -----------------------------------------------------------------------
# Das Skript nutzt die Analog-Eingaenge des MCP3208 IC
# und liest diese ueber SPI Bus aus
# Datei mcp3208-step1.py
# Pfad: /
# -----------------------------------------------------------------------
import spidev
# wget https://raw.github.com/doceme/py-spidev/master/setup.py
# wget https://raw.github.com/doceme/py-spidev/master/spidev_module.c
import time
import math
import os
# SPI Objekt erstellen
spi = spidev.SpiDev()
spi.open(0,0)
# ==============================================================================
SCLK        = 23 # Serial-Clock
MOSI        = 19 # Master-Out-Slave-In
MISO        = 21 # Master-In-Slave-Out
CS          = 24 # Chip-Select
#--------------------------------------------------------------------------------
# Funktion um Daten aus dem MCP3208 IC zu lesen
# Kanalzaehlung von 0-7
def getadcChannelMCP3208(channel):
  # Nur Kanal 0-7 erlaubt
  if ((channel > 7) or (channel < 0)):
                    return -1
  rdata = spi.xfer2([4 + (channel >> 2), (channel & 3) << 6, 0]) 
  data = ((rdata[1] & 15) << 8) + rdata[2]
  return data
# --------------------------------------------------------
# Funktion um Werte in Spannungswerte zu konvertieren
# (auf 2^12 Einheiten)
def convertVoltsMCP3208(data,places):
  volts = (data * 3.3) / 4096 # 3.3V Referenzspannung!
  volts = round(volts,places) # und runden
  return volts
# --------------------------------------------------------
def convertOhmMCP3208(data,places):
  volts = (data * 3.3) / 4096 # 3.3V Referenzspannung!
  volts = round(volts,places) # und runden
  if volts <=0:
    volts = 1
  ohms = round(((1/volts)*3300)-1000,places)
  return ohms
# --------------------------------------------------------

# ----------------------------------------------
# Start Python-Skript
# ----------------------------------------------
os.system('clear')
# Kanalnummer auswaehlen
temperaturChannel1 = 0 # rechts
temperaturChannel2 = 1
temperaturChannel3 = 2
temperaturChannel4 = 3
temperaturChannel5 = 4
temperaturChannel6 = 5
temperaturChannel7 = 6
temperaturChannel8 = 7 # links
# ---------->  max 7 !
#
# Pause zwischen Messungen
delay = 2 # Sekunden
# Anzahl der Dezimalstellen
places = 3
try:
# Dauer-Schleife
  anz_messungen = 50
  while True:
    print '=' * 100
    print "[ MCP3208 Temperatur-Sensor ] Messung..."
    # Sensor - 50  messungen
    tmp_level1 = []
    tmp_level2 = []
    tmp_level3 = []
    tmp_level4 = []
    tmp_level4 = []
    tmp_level5 = []
    tmp_level6 = []
    tmp_level7 = []
    tmp_level8 = []
    for i in range (0,anz_messungen):
        tmp_level1.append(getadcChannelMCP3208(temperaturChannel1))
        tmp_level2.append(getadcChannelMCP3208(temperaturChannel2))
        tmp_level3.append(getadcChannelMCP3208(temperaturChannel3))
        tmp_level4.append(getadcChannelMCP3208(temperaturChannel4))
        tmp_level5.append(getadcChannelMCP3208(temperaturChannel5))
        tmp_level6.append(getadcChannelMCP3208(temperaturChannel6))
        tmp_level7.append(getadcChannelMCP3208(temperaturChannel7))
        tmp_level8.append(getadcChannelMCP3208(temperaturChannel8))
    # Mittelwert errechnen
    temperaturChannel1_level = sum(tmp_level1)/anz_messungen
    temperaturChannel2_level = sum(tmp_level2)/anz_messungen
    temperaturChannel3_level = sum(tmp_level3)/anz_messungen
    temperaturChannel4_level = sum(tmp_level4)/anz_messungen
    temperaturChannel5_level = sum(tmp_level5)/anz_messungen
    temperaturChannel6_level = sum(tmp_level6)/anz_messungen
    temperaturChannel7_level = sum(tmp_level7)/anz_messungen
    temperaturChannel8_level = sum(tmp_level8)/anz_messungen
    # Spannung berechnen fuer jeden Kanal
    temperaturChannel1_volts = convertVoltsMCP3208(temperaturChannel1_level, places)
    temperaturChannel2_volts = convertVoltsMCP3208(temperaturChannel2_level, places)
    temperaturChannel3_volts = convertVoltsMCP3208(temperaturChannel3_level, places)
    temperaturChannel4_volts = convertVoltsMCP3208(temperaturChannel4_level, places)
    temperaturChannel5_volts = convertVoltsMCP3208(temperaturChannel5_level, places)
    temperaturChannel6_volts = convertVoltsMCP3208(temperaturChannel6_level, places)
    temperaturChannel7_volts = convertVoltsMCP3208(temperaturChannel7_level, places)
    temperaturChannel8_volts = convertVoltsMCP3208(temperaturChannel8_level, places)
    # Widerstand berechnen fuer jeden Kanal
    temperaturChannel1_ohm = convertOhmMCP3208(temperaturChannel1_level, places)
    temperaturChannel2_ohm = convertOhmMCP3208(temperaturChannel2_level, places)
    temperaturChannel3_ohm = convertOhmMCP3208(temperaturChannel3_level, places)
    temperaturChannel4_ohm = convertOhmMCP3208(temperaturChannel4_level, places)
    temperaturChannel5_ohm = convertOhmMCP3208(temperaturChannel5_level, places)
    temperaturChannel6_ohm = convertOhmMCP3208(temperaturChannel6_level, places)
    temperaturChannel7_ohm = convertOhmMCP3208(temperaturChannel7_level, places)
    temperaturChannel8_ohm = convertOhmMCP3208(temperaturChannel8_level, places)
    # Datenausgabe
    print '=' * 100
    if temperaturChannel1_level > 500:
       print("| MCP3208 Temperatur Sensor #1 - Messung in  :  {} |  {} Ohm | {} V ".format(temperaturChannel1_level, temperaturChannel1_ohm, temperaturChannel1_volts))
    if temperaturChannel2_level > 500:
       print("| MCP3208 Temperatur Sensor #2 - Messung in  :  {} |  {} Ohm | {} V ".format(temperaturChannel2_level, temperaturChannel2_ohm, temperaturChannel2_volts))
    if temperaturChannel3_level > 500:
       print("| MCP3208 Temperatur Sensor #3 - Messung in  :  {} |  {} Ohm | {} V ".format(temperaturChannel3_level, temperaturChannel3_ohm, temperaturChannel3_volts))
    if temperaturChannel4_level > 500:
       print("| MCP3208 Temperatur Sensor #4 - Messung in  :  {} |  {} Ohm | {} V ".format(temperaturChannel4_level, temperaturChannel4_ohm, temperaturChannel4_volts))
    if temperaturChannel5_level > 500:
       print("| MCP3208 Temperatur Sensor #5 - Messung in  :  {} |  {} Ohm | {} V ".format(temperaturChannel5_level, temperaturChannel5_ohm, temperaturChannel5_volts))
    if temperaturChannel6_level > 500:
       print("| MCP3208 Temperatur Sensor #6 - Messung in  :  {} |  {} Ohm | {} V ".format(temperaturChannel6_level, temperaturChannel6_ohm, temperaturChannel6_volts))
    if temperaturChannel7_level > 500:
       print("| MCP3208 Temperatur Sensor #7 - Messung in  :  {} |  {} Ohm | {} V ".format(temperaturChannel7_level, temperaturChannel7_ohm, temperaturChannel7_volts))
    if temperaturChannel8_level > 500:
       print("| MCP3208 Temperatur Sensor #8 - Messung in  :  {} |  {} Ohm | {} V ".format(temperaturChannel8_level, temperaturChannel8_ohm, temperaturChannel8_volts))
    print '=' * 100
    # und warten bis zur naechsten Messung
    time.sleep(delay)
    os.system('clear')
except KeyboardInterrupt:
    # CTRL-C gedrueckt
    print "[ MCP3208 Temperatur Sensor ] Messung wurde abgebrochen."
    print '=' * 100
# ----------------------- EOF  ---------------------------
