/*
# ------------------------------------------------------------------------
# E.F.Engelhardt, Franzis Verlag, 2016
# ------------------------------------------------------------------------
# arduino_pi_mqtt_temperatur_json.ino
# ------------------------------------------------------------------------
*/
#include <SPI.h>
#include <Ethernet.h>
#include <PubSubClient.h> // http://knolleary.net/arduino-client-for-mqtt/
#include <OneWire.h> // http://www.arduino.cc/playground/Learning/OneWire
#include <DallasTemperature.h> // http://milesburton.com/index.php?title=Dallas_Temperature_Control_Library
// ------------------------------------------------------------------------------
// Pin Dateneingang Temperaturfühler
#define ONE_WIRE_BUS 2
// MAC Adresse Ethernet Shields
byte MAC_ADDRESS[] = { 0xDA, 0xEA, 0xBA, 0xFA, 0xFE, 0xED };
char macstr[] = "DAEABAFAFEED";
// IP des MQTT Servers im Heimnetz
byte localserver[] = { 192, 168, 123, 45 };
String clientName = String("d:dahoam:arduino:") + macstr;
String topicName = String("iot/event/status/fmt/json");
// ------------------------------------------------------------------------------
EthernetClient ethClient;
PubSubClient mqttClient(localserver, 1883, callback, ethClient);
OneWire oneWire(ONE_WIRE_BUS);
DallasTemperature TempSensors(&oneWire);
float tempC = 0.0;
int thresholdC = 2; // 2 Grad Abweichung
// 0 = keine abweichung
// Hilfsvariable für die Konvertierung der Temperatur zu String
char tempBuffer[100];

void setup() {
  Serial.begin(19200);
  if (Ethernet.begin(MAC_ADDRESS) == 0) {
    Serial.print("[");
    Serial.print (clientName);
    Serial.println("] Failed with DHCP");
    return;
  }
  TempSensors.begin();
}

void loop() {
  char clientStr[34];
  clientName.toCharArray(clientStr, 34);
  char topicStr[26];
  topicName.toCharArray(topicStr, 26);
  // Auslesen der Temperatur
  TempSensors.requestTemperatures();
  //if (tempC != TempSensors.getTempCByIndex(0) ) {
  if (tempC != TempSensors.getTempCByIndex(0) && ( abs(tempC - TempSensors.getTempCByIndex(0)) > thresholdC) ) {
    tempC = TempSensors.getTempCByIndex(0);
    //}     // nur bei Aenderungen publizieren
    if (!mqttClient.connected()) {
      Serial.print("[");
      Serial.print (clientName);
      Serial.print("] Trying to connect to: ");
      Serial.println(clientStr);
      mqttClient.connect(clientStr);
    }
    if (mqttClient.connected() ) {
      String json = buildJson();
      char jsonStr[200];
      json.toCharArray(jsonStr, 200);
      boolean pubresult = mqttClient.publish(topicStr, jsonStr);
      Serial.print("\n[");
      Serial.print (clientName);
      Serial.print("] attempt to send ");
      Serial.println(jsonStr);
      Serial.print("to ");
      Serial.println(topicStr);
      if (pubresult) {
        Serial.print("[");
        Serial.print (clientName);
        Serial.println ("] successfully sent");
      }
      else {
        Serial.print("[");
        Serial.print(clientName);
        Serial.println("] unsuccessfully sent");
      }
    }
  } // nur bei änderungen publizieren
  delay(10000);
}

void callback(char* topic, byte* payload, unsigned int length) {
  int i = 0;
  char message_buff[100];
  Serial.println("-------------------------------------------");
  Serial.print("\n[");
  Serial.print(clientName);
  Serial.println("] Message arrived: Topic: " + String(topic));
  Serial.println("Laenge: " + String(length, DEC));
  for (i = 0; i < length; i++) {
    message_buff[i] = payload[i];
  }
  message_buff[i] = '\0';
  String msgString = String(message_buff);
  Serial.print("[");
  Serial.print(clientName);
  Serial.println("] Payload: " + msgString);
}

String buildJson() {
  String data = "{";
  data += "\n";
  data += "\"d\": {";
  data += "\"iotName\": \"Arduino DS18B20\",";
  data += "\n";
  data += "\"temperature (C)\": ";
  data += dtostrf(tempC, 1, 2, tempBuffer);
  data += "\n";
  data += "}";
  return data;
}
// ----------------------------------- EOF ---------------------------------